# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import euclidesproto_pb2 as euclidesproto__pb2


class SimilarStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Shutdown = channel.unary_unary(
        '/euclidesproto.Similar/Shutdown',
        request_serializer=euclidesproto__pb2.ShutdownRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.ShutdownReply.FromString,
        )
    self.FindSimilar = channel.unary_unary(
        '/euclidesproto.Similar/FindSimilar',
        request_serializer=euclidesproto__pb2.FindSimilarRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.FindSimilarReply.FromString,
        )
    self.AddImage = channel.unary_unary(
        '/euclidesproto.Similar/AddImage',
        request_serializer=euclidesproto__pb2.AddImageRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.AddImageReply.FromString,
        )
    self.RemoveImage = channel.unary_unary(
        '/euclidesproto.Similar/RemoveImage',
        request_serializer=euclidesproto__pb2.RemoveImageRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.RemoveImageReply.FromString,
        )


class SimilarServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Shutdown(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FindSimilar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddImage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveImage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SimilarServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Shutdown': grpc.unary_unary_rpc_method_handler(
          servicer.Shutdown,
          request_deserializer=euclidesproto__pb2.ShutdownRequest.FromString,
          response_serializer=euclidesproto__pb2.ShutdownReply.SerializeToString,
      ),
      'FindSimilar': grpc.unary_unary_rpc_method_handler(
          servicer.FindSimilar,
          request_deserializer=euclidesproto__pb2.FindSimilarRequest.FromString,
          response_serializer=euclidesproto__pb2.FindSimilarReply.SerializeToString,
      ),
      'AddImage': grpc.unary_unary_rpc_method_handler(
          servicer.AddImage,
          request_deserializer=euclidesproto__pb2.AddImageRequest.FromString,
          response_serializer=euclidesproto__pb2.AddImageReply.SerializeToString,
      ),
      'RemoveImage': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveImage,
          request_deserializer=euclidesproto__pb2.RemoveImageRequest.FromString,
          response_serializer=euclidesproto__pb2.RemoveImageReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'euclidesproto.Similar', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: euclidesproto.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='euclidesproto.proto',
  package='euclidesproto',
  syntax='proto3',
  serialized_options=_b('\n\020euclidesdb.protoB\rEuclidesProtoP\001'),
  serialized_pb=_b('\n\x13\x65uclidesproto.proto\x12\reuclidesproto\"G\n\x12\x46indSimilarRequest\x12\r\n\x05top_k\x18\x01 \x01(\x05\x12\x12\n\nimage_data\x18\x02 \x01(\x0c\x12\x0e\n\x06models\x18\x03 \x03(\t\"D\n\rSearchResults\x12\x11\n\ttop_k_ids\x18\x01 \x03(\x05\x12\x11\n\tdistances\x18\x02 \x03(\x02\x12\r\n\x05model\x18\x03 \x01(\t\"A\n\x10\x46indSimilarReply\x12-\n\x07results\x18\x01 \x03(\x0b\x32\x1c.euclidesproto.SearchResults\"_\n\x0f\x41\x64\x64ImageRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x12\x12\n\nimage_data\x18\x02 \x01(\x0c\x12\x16\n\x0eimage_metadata\x18\x03 \x01(\x0c\x12\x0e\n\x06models\x18\x04 \x03(\t\"&\n\x12RemoveImageRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"$\n\x10RemoveImageReply\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"C\n\x0bItemVectors\x12\r\n\x05model\x18\x01 \x01(\t\x12\x13\n\x0bpredictions\x18\x02 \x03(\x02\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x03(\x02\"Z\n\x08ItemData\x12\x0f\n\x07item_id\x18\x01 \x01(\x05\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12+\n\x07vectors\x18\x03 \x03(\x0b\x32\x1a.euclidesproto.ItemVectors\"<\n\rAddImageReply\x12+\n\x07vectors\x18\x01 \x03(\x0b\x32\x1a.euclidesproto.ItemVectors\"(\n\x0fShutdownRequest\x12\x15\n\rshutdown_type\x18\x01 \x01(\x05\"!\n\rShutdownReply\x12\x10\n\x08shutdown\x18\x01 \x01(\x08\x32\xcb\x02\n\x07Similar\x12J\n\x08Shutdown\x12\x1e.euclidesproto.ShutdownRequest\x1a\x1c.euclidesproto.ShutdownReply\"\x00\x12S\n\x0b\x46indSimilar\x12!.euclidesproto.FindSimilarRequest\x1a\x1f.euclidesproto.FindSimilarReply\"\x00\x12J\n\x08\x41\x64\x64Image\x12\x1e.euclidesproto.AddImageRequest\x1a\x1c.euclidesproto.AddImageReply\"\x00\x12S\n\x0bRemoveImage\x12!.euclidesproto.RemoveImageRequest\x1a\x1f.euclidesproto.RemoveImageReply\"\x00\x42#\n\x10\x65uclidesdb.protoB\rEuclidesProtoP\x01\x62\x06proto3')
)




_FINDSIMILARREQUEST = _descriptor.Descriptor(
  name='FindSimilarRequest',
  full_name='euclidesproto.FindSimilarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_k', full_name='euclidesproto.FindSimilarRequest.top_k', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_data', full_name='euclidesproto.FindSimilarRequest.image_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='euclidesproto.FindSimilarRequest.models', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=109,
)


_SEARCHRESULTS = _descriptor.Descriptor(
  name='SearchResults',
  full_name='euclidesproto.SearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_k_ids', full_name='euclidesproto.SearchResults.top_k_ids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distances', full_name='euclidesproto.SearchResults.distances', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='euclidesproto.SearchResults.model', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=179,
)


_FINDSIMILARREPLY = _descriptor.Descriptor(
  name='FindSimilarReply',
  full_name='euclidesproto.FindSimilarReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='euclidesproto.FindSimilarReply.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=246,
)


_ADDIMAGEREQUEST = _descriptor.Descriptor(
  name='AddImageRequest',
  full_name='euclidesproto.AddImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='euclidesproto.AddImageRequest.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_data', full_name='euclidesproto.AddImageRequest.image_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_metadata', full_name='euclidesproto.AddImageRequest.image_metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='euclidesproto.AddImageRequest.models', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=343,
)


_REMOVEIMAGEREQUEST = _descriptor.Descriptor(
  name='RemoveImageRequest',
  full_name='euclidesproto.RemoveImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='euclidesproto.RemoveImageRequest.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=383,
)


_REMOVEIMAGEREPLY = _descriptor.Descriptor(
  name='RemoveImageReply',
  full_name='euclidesproto.RemoveImageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='euclidesproto.RemoveImageReply.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=421,
)


_ITEMVECTORS = _descriptor.Descriptor(
  name='ItemVectors',
  full_name='euclidesproto.ItemVectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='euclidesproto.ItemVectors.model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='euclidesproto.ItemVectors.predictions', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='euclidesproto.ItemVectors.features', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=490,
)


_ITEMDATA = _descriptor.Descriptor(
  name='ItemData',
  full_name='euclidesproto.ItemData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='euclidesproto.ItemData.item_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='euclidesproto.ItemData.metadata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vectors', full_name='euclidesproto.ItemData.vectors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=582,
)


_ADDIMAGEREPLY = _descriptor.Descriptor(
  name='AddImageReply',
  full_name='euclidesproto.AddImageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='euclidesproto.AddImageReply.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=644,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='euclidesproto.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shutdown_type', full_name='euclidesproto.ShutdownRequest.shutdown_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=686,
)


_SHUTDOWNREPLY = _descriptor.Descriptor(
  name='ShutdownReply',
  full_name='euclidesproto.ShutdownReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shutdown', full_name='euclidesproto.ShutdownReply.shutdown', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=721,
)

_FINDSIMILARREPLY.fields_by_name['results'].message_type = _SEARCHRESULTS
_ITEMDATA.fields_by_name['vectors'].message_type = _ITEMVECTORS
_ADDIMAGEREPLY.fields_by_name['vectors'].message_type = _ITEMVECTORS
DESCRIPTOR.message_types_by_name['FindSimilarRequest'] = _FINDSIMILARREQUEST
DESCRIPTOR.message_types_by_name['SearchResults'] = _SEARCHRESULTS
DESCRIPTOR.message_types_by_name['FindSimilarReply'] = _FINDSIMILARREPLY
DESCRIPTOR.message_types_by_name['AddImageRequest'] = _ADDIMAGEREQUEST
DESCRIPTOR.message_types_by_name['RemoveImageRequest'] = _REMOVEIMAGEREQUEST
DESCRIPTOR.message_types_by_name['RemoveImageReply'] = _REMOVEIMAGEREPLY
DESCRIPTOR.message_types_by_name['ItemVectors'] = _ITEMVECTORS
DESCRIPTOR.message_types_by_name['ItemData'] = _ITEMDATA
DESCRIPTOR.message_types_by_name['AddImageReply'] = _ADDIMAGEREPLY
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownReply'] = _SHUTDOWNREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FindSimilarRequest = _reflection.GeneratedProtocolMessageType('FindSimilarRequest', (_message.Message,), dict(
  DESCRIPTOR = _FINDSIMILARREQUEST,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.FindSimilarRequest)
  ))
_sym_db.RegisterMessage(FindSimilarRequest)

SearchResults = _reflection.GeneratedProtocolMessageType('SearchResults', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHRESULTS,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.SearchResults)
  ))
_sym_db.RegisterMessage(SearchResults)

FindSimilarReply = _reflection.GeneratedProtocolMessageType('FindSimilarReply', (_message.Message,), dict(
  DESCRIPTOR = _FINDSIMILARREPLY,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.FindSimilarReply)
  ))
_sym_db.RegisterMessage(FindSimilarReply)

AddImageRequest = _reflection.GeneratedProtocolMessageType('AddImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDIMAGEREQUEST,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.AddImageRequest)
  ))
_sym_db.RegisterMessage(AddImageRequest)

RemoveImageRequest = _reflection.GeneratedProtocolMessageType('RemoveImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEIMAGEREQUEST,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.RemoveImageRequest)
  ))
_sym_db.RegisterMessage(RemoveImageRequest)

RemoveImageReply = _reflection.GeneratedProtocolMessageType('RemoveImageReply', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEIMAGEREPLY,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.RemoveImageReply)
  ))
_sym_db.RegisterMessage(RemoveImageReply)

ItemVectors = _reflection.GeneratedProtocolMessageType('ItemVectors', (_message.Message,), dict(
  DESCRIPTOR = _ITEMVECTORS,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.ItemVectors)
  ))
_sym_db.RegisterMessage(ItemVectors)

ItemData = _reflection.GeneratedProtocolMessageType('ItemData', (_message.Message,), dict(
  DESCRIPTOR = _ITEMDATA,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.ItemData)
  ))
_sym_db.RegisterMessage(ItemData)

AddImageReply = _reflection.GeneratedProtocolMessageType('AddImageReply', (_message.Message,), dict(
  DESCRIPTOR = _ADDIMAGEREPLY,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.AddImageReply)
  ))
_sym_db.RegisterMessage(AddImageReply)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNREQUEST,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.ShutdownRequest)
  ))
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownReply = _reflection.GeneratedProtocolMessageType('ShutdownReply', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNREPLY,
  __module__ = 'euclidesproto_pb2'
  # @@protoc_insertion_point(class_scope:euclidesproto.ShutdownReply)
  ))
_sym_db.RegisterMessage(ShutdownReply)


DESCRIPTOR._options = None

_SIMILAR = _descriptor.ServiceDescriptor(
  name='Similar',
  full_name='euclidesproto.Similar',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=724,
  serialized_end=1055,
  methods=[
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='euclidesproto.Similar.Shutdown',
    index=0,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FindSimilar',
    full_name='euclidesproto.Similar.FindSimilar',
    index=1,
    containing_service=None,
    input_type=_FINDSIMILARREQUEST,
    output_type=_FINDSIMILARREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddImage',
    full_name='euclidesproto.Similar.AddImage',
    index=2,
    containing_service=None,
    input_type=_ADDIMAGEREQUEST,
    output_type=_ADDIMAGEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveImage',
    full_name='euclidesproto.Similar.RemoveImage',
    index=3,
    containing_service=None,
    input_type=_REMOVEIMAGEREQUEST,
    output_type=_REMOVEIMAGEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIMILAR)

DESCRIPTOR.services_by_name['Similar'] = _SIMILAR

# @@protoc_insertion_point(module_scope)



import io
import grpc

from . import euclidesproto_pb2_grpc as ec_grpc
from . import euclidesproto_pb2 as ec_proto


class Channel(object):
    def __init__(self, hostname, port, options=None):
        self.hostname = hostname
        self.port = port
        self.options = options or []

        self.hostport = "{}:{}".format(hostname, port)

        self._channel = grpc.insecure_channel(
            target=self.hostport,
            options=self.options)

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, exc_traceback):
        self._channel.close()


class EuclidesDB(object):
    SHUTDOWN_REGULAR = 0
    SHUTDOWN_REFRESH = 1

    def __init__(self, channel, wire_image="jpeg"):
        self.channel = channel
        self.stub = ec_grpc.SimilarStub(self.channel._channel)
        self.wire_image = wire_image

    def add_image(self, image_id, models, image):
        bytes_img = io.BytesIO()
        image.save(bytes_img, format=self.wire_image)
        request = ec_proto.AddImageRequest()
        request.image_id = int(image_id)
        request.models.extend(models)
        request.image_data = bytes_img.getvalue()
        reply = self.stub.AddImage(request)
        return reply

    def remove_image(self, image_id):
        request = ec_proto.RemoveImageRequest()
        request.image_id = int(image_id)
        reply = self.stub.RemoveImage(request)
        return reply

    def find_similar(self, image, models, top_k=5):
        bytes_img = io.BytesIO()
        image.save(bytes_img, format=self.wire_image)
        request = ec_proto.FindSimilarRequest()
        request.models.extend(models)
        request.top_k = int(top_k)
        request.image_data = bytes_img.getvalue()
        reply = self.stub.FindSimilar(request)
        return reply

    def __shutdown(self, shutdown_type):
        request = ec_proto.ShutdownRequest()
        request.shutdown_type = shutdown_type
        reply = self.stub.Shutdown(request)
        return reply

    def refresh_index(self):
        self.__shutdown(EuclidesDB.SHUTDOWN_REFRESH)

    def shutdown(self):
        self.__shutdown(EuclidesDB.SHUTDOWN_REGULAR)




from setuptools import setup, find_packages
from codecs import open
from os import path

import euclides as ec

here = path.abspath(path.dirname(__file__))

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setup(
    name='euclides',
    version=ec.__version__,
    description='EuclidesDB Python client API.',
    url='https://github.com/perone/euclidesdb',
    author='Christian S. Perone',
    author_email='christian.perone@gmail.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
    ],
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=requirements,
    # entry_points={
        # 'console_scripts': [
        #    'cmdname=medicaltorch.mod:function',
        # ],
    # },
)
